import axios from "axios";
import { appConfig } from "./config";
import { getToken } from "./auth";
import { Message } from "element-ui";
// import store from '../store/index';
const service = axios.create({
  baseURL: process.env.NODE_ENV === 'production' ? appConfig.apiUrl : '',
  // baseURL: appConfig.apiUrl,
  timeout: 60000
});

service.interceptors.request.use(
  config => {
    config.headers["Blade-Auth"] = 'bearer ' + getToken()
    return config;
  }, error => {
    return Promise.reject(error);
  }
);

service.interceptors.response.use(
  response => {
    // 响应拦截器
    const status = response.data.code || response.status;
    const message = response.data.msg || response.data.error_description || '未知错误';
    if (status == 401) {
      Message.error('请求未授权!');
      //刷新跳转到登录页
      // window.location.href = './';
      return false
    }
    if (status !== 200) {
      Message.error(message);
    }
    return response.data;
  }, (error) => {
    if (error.response.status == 401) {
      Message.error('请求未授权!');
    }
    return Promise.reject(error);
  }
);

export default service;
